==> Marconi-2955-Radio-Communications-Test-Set-Software-CV-VGA-PCB-Version-2-1.0.zip: MI2955_CV_VGA_PCBV2_V1.0/CV_PCBV2_V1.0.h <==
/*********************************************************************
Based on the Arduino VGA library by https://simple-circuit.com/
The Arduino VGA library is also based on the VGAX Library at https://github.com/smaffer/vgax
*********************************************************************/
//Modified and optimised by K. Jardine for the MI2955 Composite Video & VGA board, 19th March 2021
//This code is specifically for Composite Video for PCB Versions 2.3 & 2.4

#ifndef _CV_PCBV2_V1_0_H
#define _CV_PCBV2_V1_0_H

#if defined(ARDUINO) && ARDUINO >= 100
  #include "Arduino.h"
#else
  #include "WProgram.h"
  #include "pins_arduino.h"
#endif

#define _CYCLES_PER_US			(F_CPU / 1000000) //Defines the processor speed

//PAL definitions
#define PALscrollRows 3 //The number of character rows scrolled when in PAL
#define PALCcorrectionOffset 0 //The number of character rows offset when in PAL to set the reference display position
#define _PAL_TIME_SCANLINE 64 //uS
#define PAL_CYCLES_SCANLINE	 ((_PAL_TIME_SCANLINE * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync period
#define _PAL_TIME_HORZ_SYNC	4.7 //uS
#define PAL_CYCLES_HORZ_SYNC ((_PAL_TIME_HORZ_SYNC * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync pulse duration
#define _PAL_TIME_VERT_SYNC	58.85 //uS
#define PAL_CYCLES_VERT_SYNC ((_PAL_TIME_VERT_SYNC * _CYCLES_PER_US) - 1) //The Horizontal Sync pulse duration (Inverted Line Sync) during the Vertical Sync pulse
#define PAL_LINES 312 //The number of lines in a PAL frame
#define PAL_LINE_CHANGE 7 //The line where the Inverted Line Sync reverts to Non Inverted Line Sync. Inverted Line Sync occurs during the Vertical Sync pulse
#define PAL_VIDEO_HEIGHT 256 //Defines the number of lines forming the image
#define PAL_VIDEO_WIDTH 55 //Note that fine tuning of the image width can be done in the Timer1 Overflow Interrupt Service Routine but it will affect both PAL & NTSC
#define PAL_START_LINE 20 //Start line
#define PAL_END_LINE (PAL_START_LINE + PAL_VIDEO_HEIGHT) //End line
#define _PAL_TIME_OUTPUT_START 14 //uS
#define PAL_CYCLES_OUTPUT_START ((_PAL_TIME_OUTPUT_START * _CYCLES_PER_US) - 1) //Determines the starting position across the line

//NTSC definitions
#define NTSCscrollRows 4 //The number of character rows scrolled when in NTSC
#define NTSCcorrectionOffset 1 //The number of character rows offset when in NTSC to set the reference display position
#define _NTSC_TIME_SCANLINE  63.55 //uS
#define NTSC_CYCLES_SCANLINE  ((_NTSC_TIME_SCANLINE * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync period
#define _NTSC_TIME_HORZ_SYNC  4.7 //uS
#define NTSC_CYCLES_HORZ_SYNC ((_NTSC_TIME_HORZ_SYNC * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync pulse duration
#define _NTSC_TIME_VERT_SYNC  58.85 //uS
#define NTSC_CYCLES_VERT_SYNC ((_NTSC_TIME_VERT_SYNC * _CYCLES_PER_US) - 1) //The Horizontal Sync pulse duration (Inverted Line Sync) during the Vertical Sync pulse
#define NTSC_LINES 262 //The number of lines in a NTSC frame
#define NTSC_LINE_CHANGE 3 //The line where the Inverted Line Sync reverts to Non Inverted Line Sync. Inverted Line Sync occurs during the Vertical Sync pulse
#define NTSC_VIDEO_HEIGHT 216 //Defines the number of lines forming the image
#define NTSC_VIDEO_WIDTH 53 //Note that fine tuning of the image width can be done in the Timer1 Overflow Interrupt Service Routine but it will affect both PAL & NTSC
#define NTSC_START_LINE 23 //Start line
#define NTSC_END_LINE (NTSC_START_LINE + NTSC_VIDEO_HEIGHT) //End line
#define _NTSC_TIME_OUTPUT_START 12 //uS
#define NTSC_CYCLES_OUTPUT_START ((_NTSC_TIME_OUTPUT_START * _CYCLES_PER_US) - 1) //Determines the starting position across the line

class CV {
  public:
  void begin(bool NTSC_PAL);
};

extern const byte VCClk; //Port D7, Vertical Counter Clock Output
extern const byte VCC; //Port D11, Vertical Counter Clear Output
extern const byte VCCPortBpin3; //Port D11, Vertical Counter Clear Output, PortB Pin
extern const byte HCCPortBpin2; //Port D10, Horizontal Counter Clear Output, PortB Pin
extern const byte HCC; //Port D10, Horizontal Counter Clear Output
extern const byte VOE; //Port D6, Video Out Enable
extern const byte FS_LS; //Port D9, Composite Video Frame Sync/Line Sync Output
extern const byte FS_LSPortBpin1; //Port D9, Composite Video Frame Sync/Line Sync Output PortB Pin 1
extern uint16_t line; //Line counter for counting the lines down the screen
extern uint8_t width; //The image width variable for counting image placement across the screen
extern bool bool_scroll; //Scroll if false. No scroll if true. Scrolls 8 lines when NTSC or 3 lines when PAL.
extern int8_t height_offset; //An offset to adjust the screen image height
extern int8_t start_line_offset; //An offset to adjust the image position down the screen
extern int scroll_offset; //An offset to adjust the scroll value
extern int scroll_cntr; //To debounce the scroll button

#endif

==> Marconi-2955-Radio-Communications-Test-Set-Software-CV-VGA-PCB-Version-2-2.0.zip: MI2955_CV_VGA_PCBV2_V2.0/CV_PCBV2_V2.0.h <==
/*********************************************************************
Based on the Arduino VGA library by https://simple-circuit.com/
The Arduino VGA library is also based on the VGAX Library at https://github.com/smaffer/vgax
*********************************************************************/
//Modified and optimised by K. Jardine for the MI2955 Composite Video & VGA board, 19th March 2021
//Updated to V2.0 Dated Dated 11th June 2021 - Comments and defines updated only.
//This code is specifically for Composite Video for PCB Versions 2.3 and above.

#ifndef _CV_PCBV2_V2_0_H
#define _CV_PCBV2_V2_0_H

#if defined(ARDUINO) && ARDUINO >= 100
  #include "Arduino.h"
#else
  #include "WProgram.h"
  #include "pins_arduino.h"
#endif

#define _CYCLES_PER_US			(F_CPU / 1000000) //Defines the processor speed

//PAL definitions
#define PALscrollRows 3 //The number of character rows scrolled when in PAL
#define PALCcorrectionOffset 0 //The number of character rows offset when in PAL to set the reference display position
#define _PAL_TIME_SCANLINE 64 //uS
#define PAL_CYCLES_SCANLINE	 ((_PAL_TIME_SCANLINE * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync period
#define _PAL_TIME_HORZ_SYNC	4.7 //uS
#define PAL_CYCLES_HORZ_SYNC ((_PAL_TIME_HORZ_SYNC * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync pulse duration
#define _PAL_TIME_VERT_SYNC	58.85 //uS
#define PAL_CYCLES_VERT_SYNC ((_PAL_TIME_VERT_SYNC * _CYCLES_PER_US) - 1) //The Horizontal Sync pulse duration (Inverted Line Sync) during the Vertical Sync pulse
#define PAL_LINES 312 //The number of lines in a PAL frame
#define PAL_LINE_CHANGE 7 //The line where the Inverted Line Sync reverts to Non Inverted Line Sync. Inverted Line Sync occurs during the Vertical Sync pulse
#define PAL_VIDEO_HEIGHT 256 //Defines the number of lines forming the image
#define PAL_VIDEO_WIDTH 55 //Note that fine tuning of the image width can be done in the Timer1 Overflow Interrupt Service Routine but it will affect both PAL & NTSC
#define PAL_START_LINE 20 //Start line
#define PAL_END_LINE (PAL_START_LINE + PAL_VIDEO_HEIGHT) //End line
#define _PAL_TIME_OUTPUT_START 14 //uS
#define PAL_CYCLES_OUTPUT_START ((_PAL_TIME_OUTPUT_START * _CYCLES_PER_US) - 1) //Determines the starting position across the line

//NTSC definitions
#define NTSCscrollRows 4 //The number of character rows scrolled when in NTSC
#define NTSCcorrectionOffset 1 //The number of character rows offset when in NTSC to set the reference display position
#define _NTSC_TIME_SCANLINE  63.55 //uS
#define NTSC_CYCLES_SCANLINE  ((_NTSC_TIME_SCANLINE * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync period
#define _NTSC_TIME_HORZ_SYNC  4.7 //uS
#define NTSC_CYCLES_HORZ_SYNC ((_NTSC_TIME_HORZ_SYNC * _CYCLES_PER_US) - 1) //Sets the Horizontal Sync pulse duration
#define _NTSC_TIME_VERT_SYNC  58.85 //uS
#define NTSC_CYCLES_VERT_SYNC ((_NTSC_TIME_VERT_SYNC * _CYCLES_PER_US) - 1) //The Horizontal Sync pulse duration (Inverted Line Sync) during the Vertical Sync pulse
#define NTSC_LINES 262 //The number of lines in a NTSC frame
#define NTSC_LINE_CHANGE 3 //The line where the Inverted Line Sync reverts to Non Inverted Line Sync. Inverted Line Sync occurs during the Vertical Sync pulse
#define NTSC_VIDEO_HEIGHT 216 //Defines the number of lines forming the image
#define NTSC_VIDEO_WIDTH 53 //Note that fine tuning of the image width can be done in the Timer1 Overflow Interrupt Service Routine but it will affect both PAL & NTSC
#define NTSC_START_LINE 23 //Start line
#define NTSC_END_LINE (NTSC_START_LINE + NTSC_VIDEO_HEIGHT) //End line
#define _NTSC_TIME_OUTPUT_START 12 //uS
#define NTSC_CYCLES_OUTPUT_START ((_NTSC_TIME_OUTPUT_START * _CYCLES_PER_US) - 1) //Determines the starting position across the line

class CV {
  public:
  void begin(bool NTSC_PAL);
};

extern const byte VCClk; //Port D7, Vertical Counter Clock Output
extern const byte VCC; //Port D11, Vertical Counter Clear Output
extern const byte VCCPortBpin3; //Port D11, Vertical Counter Clear Output, PortB Pin
extern const byte HCCPortBpin2; //Port D10, Horizontal Counter Clear Output, PortB Pin
extern const byte HCC; //Port D10, Horizontal Counter Clear Output
extern const byte VOE; //Port D6, Video Out Enable
extern const byte FS_LS; //Port D9, Composite Video Frame Sync/Line Sync Output
extern const byte FS_LSPortBpin1; //Port D9, Composite Video Frame Sync/Line Sync Output PortB Pin 1
extern uint16_t line; //Line counter for counting the lines down the screen
extern uint8_t width; //The image width variable for counting image placement across the screen
extern bool bool_scroll; //Scroll if false. No scroll if true. Scrolls 8 lines when NTSC or 3 lines when PAL.
extern int8_t height_offset; //An offset to adjust the screen image height
extern int8_t start_line_offset; //An offset to adjust the image position down the screen
extern int scroll_offset; //An offset to adjust the scroll value
extern int scroll_cntr; //To debounce the scroll button

#endif
